@@ -30,10 +30,10 @@ class PentahoCarteHook(BaseHook):
     class PentahoCarteClient:
         """Implementation for Carte calls"""
 
-        RUN_JOB = '/kettle/executeJob/'
-        JOB_STATUS = '/kettle/jobStatus/'
-        RUN_TRANS = '/kettle/executeTrans/'
-        TRANS_STATUS = '/kettle/transStatus/'
+        RUN_JOB_ENDPOINT = '/kettle/executeJob/'
+        JOB_STATUS_ENDPOINT = '/kettle/jobStatus/'
+        RUN_TRANS_ENDPOINT = '/kettle/executeTrans/'
+        TRANS_STATUS_ENDPOINT = '/kettle/transStatus/'
 
         def __init__(
                 self,
@@ -49,6 +49,8 @@ class PentahoCarteHook(BaseHook):
                 **kwargs):
             super().__init__(*args, **kwargs)
             self.host = host
+            if not self.host.startswith('http'):
+                self.host = 'http://{}'.format(self.host)
             self.port = port
             self.rep = rep
             self.username = username
@@ -57,14 +59,14 @@ class PentahoCarteHook(BaseHook):
             self.carte_password = carte_password
             self.level = level
 
-        def __get_url(self, method):
-            return 'http://{}:{}{}'.format(self.host, self.port, method)
+        def __get_url(self, endpoint):
+            return '{}:{}{}'.format(self.host, self.port, endpoint)
 
         def __get_auth(self):
             return HTTPBasicAuth(self.carte_username, self.carte_password)
 
         def job_status(self, job_name, job_id, previous_response=None):
-            url = self.__get_url(self.JOB_STATUS)
+            url = self.__get_url(self.JOB_STATUS_ENDPOINT)
             headers = {'Content-Type': 'application/x-www-form-urlencoded'}
 
             from_line = previous_response['jobstatus']['last_log_line_nr'] \
@@ -90,7 +92,7 @@ class PentahoCarteHook(BaseHook):
                 return xmltodict.parse(rs.content)
 
         def run_job(self, job_path, params=None):
-            url = self.__get_url(self.RUN_JOB)
+            url = self.__get_url(self.RUN_JOB_ENDPOINT)
             args = {
                 'user': self.username,
                 'pass': self.password,
@@ -113,7 +115,7 @@ class PentahoCarteHook(BaseHook):
                 return xmltodict.parse(rs.content)
 
         def trans_status(self, trans_name, previous_response=None):
-            url = self.__get_url(self.TRANS_STATUS)
+            url = self.__get_url(self.TRANS_STATUS_ENDPOINT)
             headers = {'Content-Type': 'application/x-www-form-urlencoded'}
 
             from_line = previous_response['transstatus']['last_log_line_nr'] \
@@ -138,7 +140,7 @@ class PentahoCarteHook(BaseHook):
                 return xmltodict.parse(rs.content)
 
         def run_trans(self, trans_path, params=None):
-            url = self.__get_url(self.RUN_TRANS)
+            url = self.__get_url(self.RUN_TRANS_ENDPOINT)
             args = {
                 'user': self.username,
                 'pass': self.password,
